@@ -2,12 +2,12 @@ use crate::{
     EntityChannelMessage, EntityError, Identity, LocalInfo, ProfileIdentifier,
     SecureChannelTrustInfo, TrustPolicy,
 };
-use async_trait::async_trait;
 use core::future::Future;
 use core::pin::Pin;
 use ockam_channel::{
     CreateResponderChannelMessage, KeyExchangeCompleted, SecureChannel, SecureChannelInfo,
 };
+use ockam_core::async_trait;
 use ockam_core::compat::rand::random;
 use ockam_core::compat::{boxed::Box, vec::Vec};
 use ockam_core::{
@@ -85,7 +85,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
         route: Route,
         identity: I,
         trust_policy: T,
-        vault: impl XXVault + Sync,
+        vault: impl XXVault,
     ) -> Result<Address> {
         let child_address = Address::random(0);
         let mut child_ctx = ctx.new_context(child_address.clone()).await?;
@@ -96,7 +96,9 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
         let self_local_address: Address = random();
         let self_remote_address: Address = random();
 
-        let initiator = XXNewKeyExchanger::new(vault.clone()).initiator()?;
+        let initiator = XXNewKeyExchanger::new(vault.async_try_clone().await?)
+            .initiator()
+            .await?;
         // Create regular secure channel and set self address as first responder
         let temp_ctx = ctx.new_context(Address::random(0)).await?;
         let self_remote_address_clone = self_remote_address.clone();
@@ -172,7 +174,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
 
         // Change completed callback address and forward message for regular key exchange to happen
         let body = CreateResponderChannelMessage::new(
-            body.payload().clone(),
+            body.payload().to_vec(),
             Some(self_local_address.clone()),
         );
 
@@ -213,12 +215,15 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
         msg: Routed<<Self as Worker>::Message>,
         mut state: ResponderWaitForKex<I, T>,
     ) -> Result<()> {
-        let kex_msg = KeyExchangeCompleted::decode(&msg.payload())?;
+        let kex_msg = KeyExchangeCompleted::decode(msg.payload())?;
 
         // Prove we posses Profile key
-        let proof = state.identity.create_auth_proof(&kex_msg.auth_hash())?;
+        let proof = state
+            .identity
+            .create_auth_proof(&kex_msg.auth_hash())
+            .await?;
         let msg = EntityChannelMessage::Request {
-            contact: state.identity.as_contact()?,
+            contact: state.identity.as_contact().await?,
             proof,
         };
         ctx.send_from_address(
@@ -262,20 +267,19 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
             let their_contact = contact;
             let their_profile_id = their_contact.identifier().clone();
 
-            let contact_result = state.identity.get_contact(&their_profile_id);
+            let contact_result = state.identity.get_contact(&their_profile_id).await?;
 
-            if let Some(_) = contact_result? {
+            if contact_result.is_some() {
                 // TODO: We're creating SecureChannel with known Profile. Need to update their Profile.
             } else {
-                state.identity.verify_and_add_contact(their_contact)?;
+                state.identity.verify_and_add_contact(their_contact).await?;
             }
 
             // Verify responder posses their Profile key
-            let verified = state.identity.verify_auth_proof(
-                &state.channel.auth_hash(),
-                &their_profile_id,
-                proof,
-            )?;
+            let verified = state
+                .identity
+                .verify_auth_proof(&state.channel.auth_hash(), &their_profile_id, &proof)
+                .await?;
 
             if !verified {
                 return Err(EntityError::SecureChannelVerificationFailed.into());
@@ -287,7 +291,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
 
             // Check our TrustPolicy
             let trust_info = SecureChannelTrustInfo::new(their_profile_id.clone());
-            let trusted = state.trust_policy.check(&trust_info)?;
+            let trusted = state.trust_policy.check(&trust_info).await?;
             if !trusted {
                 return Err(EntityError::SecureChannelTrustCheckFailed.into());
             }
@@ -297,10 +301,11 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
             );
 
             // Prove we posses our Profile key
-            let contact = state.identity.as_contact()?;
+            let contact = state.identity.as_contact().await?;
             let proof = state
                 .identity
-                .create_auth_proof(&state.channel.auth_hash())?;
+                .create_auth_proof(&state.channel.auth_hash())
+                .await?;
 
             let auth_msg = EntityChannelMessage::Response { contact, proof };
 
@@ -329,7 +334,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
 
             Ok(())
         } else {
-            return Err(EntityError::InvalidSecureChannelInternalState.into());
+            Err(EntityError::InvalidSecureChannelInternalState.into())
         }
     }
 
@@ -356,21 +361,22 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
             let their_contact = contact;
             let their_profile_id = their_contact.identifier().clone();
 
-            let contact_result = state.identity.get_contact(&their_profile_id);
+            let contact_result = state.identity.get_contact(&their_profile_id).await?;
 
-            if let Some(_) = contact_result? {
+            if contact_result.is_some() {
                 // TODO: We're creating SecureChannel with known Profile. Need to update their Profile.
             } else {
                 state
                     .identity
-                    .verify_and_add_contact(their_contact.clone())?;
+                    .verify_and_add_contact(their_contact.clone())
+                    .await?;
             }
 
             // Verify initiator posses their Profile key
-            let verified =
-                state
-                    .identity
-                    .verify_auth_proof(state.auth_hash, &their_profile_id, proof)?;
+            let verified = state
+                .identity
+                .verify_auth_proof(&state.auth_hash, &their_profile_id, &proof)
+                .await?;
 
             if !verified {
                 return Err(EntityError::SecureChannelVerificationFailed.into());
@@ -383,7 +389,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
 
             // Check our TrustPolicy
             let trust_info = SecureChannelTrustInfo::new(their_profile_id.clone());
-            let trusted = state.trust_policy.check(&trust_info)?;
+            let trusted = state.trust_policy.check(&trust_info).await?;
             if !trusted {
                 return Err(EntityError::SecureChannelTrustCheckFailed.into());
             }
@@ -402,7 +408,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
 
             Ok(())
         } else {
-            return Err(EntityError::InvalidSecureChannelInternalState.into());
+            Err(EntityError::InvalidSecureChannelInternalState.into())
         }
     }
 
@@ -410,7 +416,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
         if let Some(s) = self.state.take() {
             Ok(s)
         } else {
-            return Err(EntityError::InvalidSecureChannelInternalState.into());
+            Err(EntityError::InvalidSecureChannelInternalState.into())
         }
     }
 
@@ -433,7 +439,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
 
         let mut onward_route = msg.onward_route();
         let mut return_route = msg.return_route();
-        let payload = msg.payload().clone();
+        let payload = msg.payload().to_vec();
 
         // Send to the other party using local regular SecureChannel
         let _ = onward_route.step()?;
@@ -479,7 +485,7 @@ impl<I: Identity, T: TrustPolicy> SecureChannelWorker<I, T> {
             return Err(EntityError::UnknownChannelMsgDestination.into());
         }
 
-        let payload = msg.payload().clone();
+        let payload = msg.payload().to_vec();
 
         // Forward to local workers
         let _ = onward_route.step()?;
