@@ -4,10 +4,8 @@ use ockam_core::Error;
 /// a credential.
 #[derive(Clone, Copy, Debug)]
 pub enum CredentialError {
-    /// No error
-    None,
     /// Mismatched number of attributes in schema and provided claims to be signed
-    MismatchedAttributesAndClaims,
+    MismatchedAttributesAndClaims = 1,
     /// Mismatched attribute type and provided claim
     MismatchedAttributeClaimType,
     /// Data that cannot be converted to a claim
@@ -32,13 +30,12 @@ impl CredentialError {
     /// Integer code associated with the error domain.
     pub const DOMAIN_CODE: u32 = 33_000;
 
-    #[cfg(any(feature = "std", feature = "alloc"))]
+    #[cfg(feature = "alloc")]
     /// Descriptive name for the error domain
     pub const DOMAIN_NAME: &'static str = "OCKAM_CREDENTIAL";
 
     pub(crate) const fn as_u32(self) -> u32 {
         match self {
-            CredentialError::None => 0,
             CredentialError::MismatchedAttributesAndClaims => 100,
             CredentialError::MismatchedAttributeClaimType => 200,
             CredentialError::InvalidCredentialAttribute => 300,
@@ -53,7 +50,7 @@ impl CredentialError {
     }
 }
 
-#[cfg(any(feature = "std", feature = "alloc"))]
+#[cfg(feature = "alloc")]
 impl From<CredentialError> for Error {
     fn from(v: CredentialError) -> Error {
         let t = v.as_u32();
@@ -64,7 +61,7 @@ impl From<CredentialError> for Error {
     }
 }
 
-#[cfg(all(not(feature = "std"), not(feature = "alloc")))]
+#[cfg(not(feature = "alloc"))]
 impl From<CredentialError> for Error {
     fn from(v: CredentialError) -> Error {
         Error::new(CredentialError::DOMAIN_CODE + v.as_u32())
